@@ -53,7 +53,7 @@ void OnException (int signo)
     if (signo != SIGSEGV)	//SIGSEGVԼ⣬ʱִбܻ뷨ļ
 	SaveIM ();
 
-    if (signo != SIGCHLD && signo != SIGQUIT && signo != SIGWINCH) {
+    if (signo != SIGCHLD && signo != SIGQUIT && signo != SIGWINCH && signo != SIGTTIN) {
 	fprintf (stderr, "FCITX -- Exit Signal No.: %d\n\n", signo);
 	exit (0);
     }
