@@ -5,7 +5,9 @@
 /* ***********************************************************
  * Consts
  * *********************************************************** */
-
+#ifndef SIGUNUSED
+#define SIGUNUSED 29
+#endif
 /* ***********************************************************
  * Data structures
  * *********************************************************** */
