@@ -61,6 +61,7 @@ int             i3rdSelectKey = 0;	//ѡѡΪɨ
 Time            lastKeyPressedTime;
 
 KEY_RELEASED    keyReleased = KR_OTHER;
+Bool		bDoubleSwitchKey = False;
 KEYCODE         switchKey = L_CTRL;
 
 //ȼ
@@ -82,7 +83,7 @@ Bool            bUseSP = False;
 Bool            bUseQW = True;
 Bool            bUseTable = True;
 
-Bool            bLumaQQ = True;
+Bool            bLumaQQ = False;
 
 //++++++++++++++++++++++++++++++++++++++++
 /*
@@ -90,6 +91,7 @@ INT8		iKeyPressed = 0;
 Bool		bRelease = True;
 */
 
+extern XIMS     ims;
 extern IC      *CurrentIC;
 extern Display *dpy;
 extern ChnPunc *chnPunc;
@@ -124,6 +126,11 @@ extern INT8     iTableCount;
 
 extern Bool     bTrigger;
 
+extern int      iInputWindowX;
+extern int      iInputWindowY;
+extern int      iTempInputWindowX;
+extern int      iTempInputWindowY;
+
 #ifdef _USE_XFT
 extern XftFont *xftMainWindowFont;
 #else
@@ -162,7 +169,7 @@ void ResetInput (void)
 	im[iIMIndex].ResetIM ();
 }
 
-void CloseIM (XIMS ims, IMForwardEventStruct * call_data)
+void CloseIM (IMForwardEventStruct * call_data)
 {
     XUnmapWindow (dpy, inputWindow);
     IMPreeditEnd (ims, (XPointer) call_data);
@@ -170,8 +177,29 @@ void CloseIM (XIMS ims, IMForwardEventStruct * call_data)
     DisplayMainWindow ();
 }
 
+void ChangeIMState(IMForwardEventStruct * call_data)
+{
+    if (ConnectIDGetState (call_data->connect_id) == IS_ENG) {
+	SetConnectID (call_data->connect_id, IS_CHN);
+	DisplayInputWindow ();
+	
+	if ( ConnectIDGetTrackCursor (call_data->connect_id) )
+	    XMoveWindow (dpy, inputWindow, iTempInputWindowX, iTempInputWindowY);
+	else
+	    XMoveWindow (dpy, inputWindow, iInputWindowX, iInputWindowY);
+    }
+    else {
+	SetConnectID (call_data->connect_id, IS_ENG);
+	ResetInput ();
+	ResetInputWindow ();
+	XUnmapWindow (dpy, inputWindow);
+    }
+    if (hideMainWindow != HM_HIDE)
+	DisplayMainWindow ();
+}
+
 //FILE           *fd;
-void ProcessKey (XIMS ims, IMForwardEventStruct * call_data)
+void ProcessKey (IMForwardEventStruct * call_data)
 {
     KeySym          keysym;
     XKeyEvent      *kev;
@@ -182,6 +210,7 @@ void ProcessKey (XIMS ims, IMForwardEventStruct * call_data)
     int             iKey;
     char           *pstr;
     int             iLen;
+ //   IC		   *ic;
 
     kev = (XKeyEvent *) & call_data->event;
     memset (strbuf, 0, STRBUFLEN);
@@ -200,9 +229,11 @@ void ProcessKey (XIMS ims, IMForwardEventStruct * call_data)
      * xineкѡԶѡе
      * xineÿӲһSHIFTͷ¼
      */
+    /*ic=(IC *)FindIC (call_data->icid);
+    /printf("%d %d %d %d %d %d\n",kev->same_screen,ic->focus_win,ic->client_win,kev->window,kev->root,kev->subwindow); */
     if (kev->same_screen && (kev->keycode == switchKey || kev->keycode == i2ndSelectKey || kev->keycode == i3rdSelectKey))
-	return;
-
+    	return;
+    
     retVal = IRV_TO_PROCESS;
 
     if (call_data->event.type == KeyRelease) {
@@ -211,27 +242,16 @@ void ProcessKey (XIMS ims, IMForwardEventStruct * call_data)
 		if (ConnectIDGetState (call_data->connect_id) == IS_CHN)
 		    SwitchIM (-1);
 		else if (IsHotKey (iKey, hkTrigger))
-		    CloseIM (ims, call_data);
+		    CloseIM (call_data);
 	    }
 	    else if (!bLocked && iKey == CTRL_LSHIFT) {
 		if (ConnectIDGetState (call_data->connect_id) == IS_CHN)
 		    SwitchIM (-1);
 		else if (IsHotKey (iKey, hkTrigger))
-		    CloseIM (ims, call_data);
+		    CloseIM (call_data);
 	    }
-	    else if (kev->keycode == switchKey && keyReleased == KR_CTRL) {
-		if (ConnectIDGetState (call_data->connect_id) == IS_ENG) {
-		    SetConnectID (call_data->connect_id, IS_CHN);
-		    DisplayInputWindow ();
-		}
-		else {
-		    SetConnectID (call_data->connect_id, IS_ENG);
-		    ResetInput ();
-		    ResetInputWindow ();
-		    XUnmapWindow (dpy, inputWindow);
-		}
-		if (hideMainWindow != HM_HIDE)
-		    DisplayMainWindow ();
+	    else if (kev->keycode == switchKey && keyReleased == KR_CTRL && !bDoubleSwitchKey) {
+	        ChangeIMState(call_data);
 		retVal = IRV_DO_NOTHING;
 	    }
 	    else if (kev->keycode == i2ndSelectKey && keyReleased == KR_2ND_SELECTKEY) {
@@ -249,6 +269,11 @@ void ProcessKey (XIMS ims, IMForwardEventStruct * call_data)
 		    else
 			retVal = IRV_TO_PROCESS;
 		}
+		else {
+			strcpy(strStringGet, " ");
+			uMessageDown = 0;
+			retVal = IRV_GET_CANDWORDS;
+		}
 	    }
 	    else if (kev->keycode == i3rdSelectKey && keyReleased == KR_3RD_SELECTKEY) {
 		if (!bIsInLegend) {
@@ -263,21 +288,48 @@ void ProcessKey (XIMS ims, IMForwardEventStruct * call_data)
 		    else if (iCandWordCount)
 			retVal = IRV_DISPLAY_CANDWORDS;
 		}
+		else {
+			strcpy(strStringGet, "");
+			uMessageDown = 0;
+			retVal = IRV_GET_CANDWORDS;
+		}
 	    }
 	}
     }
 
     if (retVal == IRV_TO_PROCESS) {
 	if (call_data->event.type == KeyPress) {
+	    if (kev->keycode != switchKey )
+		keyReleased = KR_OTHER;
+	    else {
+	        if ( (keyReleased == KR_CTRL) && (kev->time-lastKeyPressedTime<250) && bDoubleSwitchKey) 
+		    ChangeIMState(call_data);
+	    }
+	    
 	    lastKeyPressedTime = kev->time;
-	    keyReleased = KR_OTHER;
 	    if (kev->keycode == switchKey) {
 		keyReleased = KR_CTRL;
+		//retVal = (bDoubleSwitchKey)? IRV_CLEAN:IRV_DO_NOTHING;
 		retVal = IRV_DO_NOTHING;
 	    }
 	    else if (IsHotKey (iKey, hkTrigger)) {
-		CloseIM (ims, call_data);
-		retVal = IRV_DO_NOTHING;
+		if (ConnectIDGetState (call_data->connect_id) == IS_ENG) {
+		    SetConnectID (call_data->connect_id, IS_CHN);
+		    DisplayInputWindow ();
+		    
+		    if ( ConnectIDGetTrackCursor (call_data->connect_id) )
+			XMoveWindow (dpy, inputWindow, iTempInputWindowX, iTempInputWindowY);
+		    else
+			XMoveWindow (dpy, inputWindow, iInputWindowX, iInputWindowY);
+
+		    if (hideMainWindow != HM_HIDE)
+			DisplayMainWindow ();
+
+		}
+		else {
+			CloseIM (call_data);
+			retVal = IRV_DO_NOTHING;
+		}
 	    }
 	}
 	if (retVal == IRV_TO_PROCESS && (ConnectIDGetState (call_data->connect_id) == IS_CHN)) {
@@ -318,7 +370,7 @@ void ProcessKey (XIMS ims, IMForwardEventStruct * call_data)
 				iCandWordCount = 0;
 				if (pstr) {
 				    strcpy (strStringGet, pstr);
-				    SendHZtoClient (ims, call_data, strStringGet);
+				    SendHZtoClient (call_data, strStringGet);
 				    iCodeInputCount = 0;
 				}
 			    }
@@ -342,8 +394,11 @@ void ProcessKey (XIMS ims, IMForwardEventStruct * call_data)
 
 			if (retVal == IRV_TO_PROCESS) {
 			    if (bInCap) {
-				if (iKey == ' ' && iCodeInputCount == 0) {
-				    strcpy (strStringGet, "");
+				if (iKey == ' ') {
+				    if (iCodeInputCount == 0)
+					strcpy (strStringGet, "");
+				    else
+					strcpy(strStringGet,strCodeInput);
 				    retVal = IRV_ENG;
 				    bInCap = False;
 				}
@@ -354,6 +409,8 @@ void ProcessKey (XIMS ims, IMForwardEventStruct * call_data)
 					if (!bEngAfterSemicolon || !(bEngAfterSemicolon && (iCodeInputCount == 0 && iKey == ';'))) {
 					    strCodeInput[iCodeInputCount++] = iKey;
 					    strCodeInput[iCodeInputCount] = '\0';
+					    bShowCursor = True;
+					    iCursorPos = iCodeInputCount;
 					}
 					retVal = IRV_DISPLAY_MESSAGE;
 				    }
@@ -374,7 +431,7 @@ void ProcessKey (XIMS ims, IMForwardEventStruct * call_data)
 				}
 				else {
 				    strcpy (messageUp[0].strMsg, strCodeInput);
-				    strcpy (messageDown[0].strMsg, " Enter Ӣ");
+				    strcpy (messageDown[0].strMsg, " Enter/ո Ӣ");
 				}
 				messageUp[0].type = MSG_INPUT;
 				messageDown[0].type = MSG_TIPS;
@@ -555,7 +612,7 @@ void ProcessKey (XIMS ims, IMForwardEventStruct * call_data)
 	DisplayInputWindow ();
 	break;
     case IRV_GET_LEGEND:
-	SendHZtoClient (ims, call_data, strStringGet);
+	SendHZtoClient (call_data, strStringGet);
 	if (iLegendCandWordCount) {
 	    bShowNext = bShowPrev = False;
 	    if (iCurrentLegendCandPage > 0)
@@ -589,7 +646,7 @@ void ProcessKey (XIMS ims, IMForwardEventStruct * call_data)
     case IRV_GET_CANDWORDS_NEXT:
 	if (retVal == IRV_GET_CANDWORDS_NEXT || lastIsSingleHZ == -1)
 	    DisplayInputWindow ();
-	SendHZtoClient (ims, call_data, strStringGet);
+	SendHZtoClient (call_data, strStringGet);
 	bLastIsNumber = False;
 	lastIsSingleHZ = 0;
 
@@ -635,7 +692,7 @@ INPUT_RETURN_VALUE ChangeGBK (void)
     ResetInputWindow ();
 
     DisplayMainWindow ();
-    DisplayInputWindow ();
+    XUnmapWindow (dpy, inputWindow);
 
     SaveProfile ();
 
@@ -645,7 +702,11 @@ INPUT_RETURN_VALUE ChangeGBK (void)
 INPUT_RETURN_VALUE ChangeLegend (void)
 {
     bUseLegend = !bUseLegend;
+    ResetInput ();
+    ResetInputWindow ();
+
     DisplayMainWindow ();
+    XUnmapWindow (dpy, inputWindow);
 
     SaveProfile ();
 
