@@ -59,6 +59,7 @@ INT8            iOrderCount = 0;
 INT8            iNewFreqCount = 0;
 
 INT8            iYCDZ = 0;
+char            cPYYCDZ[3] = "[]";	//Դʶ
 
 HOTKEYS         hkPYAddFreq[HOT_KEY_COUNT] = { CTRL_8, 0 };
 Bool            bIsPYAddFreq = False;
@@ -438,7 +439,6 @@ INPUT_RETURN_VALUE DoPYInput (int iKey)
 	LoadPYOtherDict ();
 
     val = IRV_TO_PROCESS;
-
     if (!bIsPYAddFreq && !bIsPYDelFreq && !bIsPYDelUserPhr) {
 	if ((iKey >= 'a' && iKey <= 'z') || iKey == PY_SEPERATOR || (bSP && bSP_UseSemicolon && iKey == ';')) {
 	    bIsInLegend = False;
@@ -473,7 +473,8 @@ INPUT_RETURN_VALUE DoPYInput (int iKey)
 	}
 	else if (iKey == (XK_BackSpace & 0x00FF)) {
 	    if (iPYInsertPoint) {
-		strcpy (strFindString + iPYInsertPoint - 1, strFindString + iPYInsertPoint);
+		val = ((iPYInsertPoint > 1) && (strFindString[iPYInsertPoint - 2] == PY_SEPERATOR)) ? 2 : 1;
+		strcpy (strFindString + iPYInsertPoint - val, strFindString + iPYInsertPoint);
 		ParsePY (strFindString, &findMap, PY_PARSE_INPUT_USER);
 		val = IRV_DISPLAY_CANDWORDS;
 		iPYInsertPoint--;
@@ -497,7 +498,8 @@ INPUT_RETURN_VALUE DoPYInput (int iKey)
 	else if (iKey == (XK_Delete & 0x00FF)) {
 	    if (iPYInsertPoint == strlen (strFindString))
 		return IRV_DONOT_PROCESS;
-	    strcpy (strFindString + iPYInsertPoint, strFindString + iPYInsertPoint + 1);
+	    val = (strFindString[iPYInsertPoint + 1] == PY_SEPERATOR) ? 2 : 1;
+	    strcpy (strFindString + iPYInsertPoint, strFindString + iPYInsertPoint + val);
 	    ParsePY (strFindString, &findMap, PY_PARSE_INPUT_USER);
 	    if (!strlen (strFindString))
 		return IRV_CLEAN;
@@ -702,14 +704,14 @@ INPUT_RETURN_VALUE DoPYInput (int iKey)
 
 	    //ʵԴʶ
 	    if (iCandWordCount) {
-		if (iKey == '[' || iKey == ']') {
+		if (iKey == cPYYCDZ[0] || iKey == cPYYCDZ[1]) {
 		    if (PYCandWords[iYCDZ].iWhich == PY_CAND_USERPHRASE || PYCandWords[iYCDZ].iWhich == PY_CAND_SYMPHRASE) {
 			char           *pBase, *pPhrase;
 
 			pBase = PYFAList[PYCandWords[iYCDZ].cand.phrase.iPYFA].pyBase[PYCandWords[iYCDZ].cand.phrase.iBase].strHZ;
 			pPhrase = PYCandWords[iYCDZ].cand.phrase.phrase->strPhrase;
 
-			if (iKey == '[')
+			if (iKey == cPYYCDZ[0])
 			    strcpy (strStringGet, pBase);
 			else {
 			    strncpy (strStringGet, pPhrase, 2);
@@ -719,7 +721,7 @@ INPUT_RETURN_VALUE DoPYInput (int iKey)
 			return IRV_GET_CANDWORDS;
 		    }
 		}
-		else if ( !bIsInLegend ) {
+		else if (!bIsInLegend) {
 		    val = -1;
 		    switch (iKey) {
 		    case ')':
@@ -759,8 +761,8 @@ INPUT_RETURN_VALUE DoPYInput (int iKey)
     }
 
     if (!bIsInLegend) {
-	CalculateCursorPosition ();
 	UpdateCodeInputPY ();
+	CalculateCursorPosition ();
     }
 
     if (val == IRV_DISPLAY_CANDWORDS) {
@@ -802,7 +804,10 @@ void CalculateCursorPosition (void)
     for (i = 0; i < iPYSelected; i++)
 	iCursorPos += strlen (pySelected[i].strHZ);
 
+    if (iPYInsertPoint > strlen (strFindString))
+	iPYInsertPoint = strlen (strFindString);
     iTemp = iPYInsertPoint;
+
     for (i = 0; i < findMap.iHZCount; i++) {
 	if (strlen (findMap.strPYParsed[i]) >= iTemp) {
 	    iCursorPos += iTemp;
@@ -2836,6 +2841,25 @@ void PYSetLegendCandWordsFlag (Bool flag)
 	PYLegendCandWords[i].phrase->flag = flag;
 }
 
+void PYGetPYByHZ (char *strHZ, char *strPY)
+{
+    int             i, j;
+    char            str_PY[MAX_PY_LENGTH + 1];
+
+    strPY[0] = '\0';
+    for (i = 0; i < iPYFACount; i++) {
+	if (MapToPY (PYFAList[i].strMap, str_PY)) {	
+	    for (j = 0; j < PYFAList[i].iBase; j++) {
+		if (!strcmp (PYFAList[i].pyBase[j].strHZ, strHZ)) {
+		    if (strPY[0])
+			strcat(strPY," ");
+		    strcat (strPY, str_PY);
+		    }
+	    }
+	}
+    }
+}
+
 /*
 void PP ()
 {
