@@ -49,7 +49,7 @@ typedef struct PYFREQ {
     HZ             *HZList;
     char            strPY[MAX_PY_PHRASE_LENGTH * MAX_PY_LENGTH + 1];
     uint            iCount;
-    Bool            bIsSym;	//ñʵű
+    Bool            bIsSym;	//该变量用于实现特殊符号表
     struct PYFREQ  *next;
 } PyFreq;
 
@@ -117,7 +117,7 @@ typedef union {
 
 typedef struct PYCANDWORD {
     PCand           cand;
-    uint            iWhich:3;	//0->Auto 1->ϵͳ 2->ϵͳ 3->û 4->
+    uint            iWhich:3;	//0->Auto 1->系统单字 2->系统词组 3->用户词组 4->常用字
 } PYCandWord;
 
 typedef struct PYCANDINDEX {
@@ -175,6 +175,7 @@ INPUT_RETURN_VALUE PYGetLegendCandWords (SEARCH_MODE iMode);
 Bool            PYAddLengendCandWord (PyPhrase * phrase, SEARCH_MODE mode);
 char           *PYGetLegendCandWord (int iIndex);
 void            PYSetLegendCandWordsFlag (Bool flag);
+void		PYGetPYByHZ(char *strHZ, char *strPY);
 
 //void            PP ();
 #endif
