@@ -158,6 +158,7 @@ void LoadTableInfo (void)
 	table[iTableIMIndex].strPath[0] = '\0';
 	table[iTableIMIndex].strSymbolFile[0] = '\0';
 	table[iTableIMIndex].tableOrder = AD_NO;
+	table[iTableIMIndex].bGetPY = True;
 	table[iTableIMIndex].bUsePY = True;
 	table[iTableIMIndex].cPinyin = '\0';
 	table[iTableIMIndex].bTableAutoSendToClient = True;
@@ -214,6 +215,10 @@ void LoadTableInfo (void)
 		pstr += 5;
 		table[iTableIMIndex].tableOrder = (ADJUSTORDER) atoi (pstr);
 	    }
+	    else if (!strncmp (pstr, "ƴ=", 9)) {
+		pstr += 9;
+		table[iTableIMIndex].bGetPY = atoi (pstr);
+	    }
 	    else if (!strncmp (pstr, "ƴ=", 5)) {
 		pstr += 5;
 		table[iTableIMIndex].bUsePY = atoi (pstr);
@@ -457,6 +462,13 @@ Bool LoadTableDict (void)
      * Ȼʼ뷨
      TableInit();
      */
+
+    /* 
+     * ڷ״̬Ӧƴֿ
+     */
+    if (table[iTableIMIndex].bGetPY)
+	LoadPYBaseDict ();
+
     return True;
 }
 
@@ -820,8 +832,9 @@ INPUT_RETURN_VALUE DoTableInput (int iKey)
 		    }
 		    else {
 			//ƴٵƵʽ
-			if (strCodeInput[0] == table[iTableIMIndex].cPinyin && table[iTableIMIndex].bUsePY)
+			if (strcmp (strCodeInput, table[iTableIMIndex].strSymbol) && strCodeInput[0] == table[iTableIMIndex].cPinyin && table[iTableIMIndex].bUsePY)
 			    PYGetCandWord (iKey - 1);
+
 			strcpy (strStringGet, TableGetCandWord (iKey - 1));
 			if (bIsInLegend)
 			    retVal = IRV_GET_LEGEND;
@@ -877,7 +890,7 @@ INPUT_RETURN_VALUE DoTableInput (int iKey)
 	    else if (iKey == ' ') {
 		if (!bIsInLegend) {
 		    if (!(table[iTableIMIndex].bUsePY && iCodeInputCount == 1 && strCodeInput[0] == table[iTableIMIndex].cPinyin)) {
-			if (strCodeInput[0] == table[iTableIMIndex].cPinyin && table[iTableIMIndex].bUsePY)
+			if (strcmp (strCodeInput, table[iTableIMIndex].strSymbol) && strCodeInput[0] == table[iTableIMIndex].cPinyin && table[iTableIMIndex].bUsePY)
 			    PYGetCandWord (0);
 
 			if (!iCandWordCount) {
@@ -1044,6 +1057,7 @@ INPUT_RETURN_VALUE TableGetCandWords (SEARCH_MODE mode)
     int             i;
     char            strTemp[3], *pstr;
     unsigned int    iTableTotalCandCount = 0;
+    char            strPY[10 * MAX_PY_LENGTH + 10];	//һûʮͬĶأ
 
     if (bIsInLegend)
 	return TableGetLegendCandWords (mode);
@@ -1150,6 +1164,17 @@ INPUT_RETURN_VALUE TableGetCandWords (SEARCH_MODE mode)
 	else
 	    pstr = ((tableCandWord[i].flag) ? tableCandWord[i].candWord.record->strCode : tableCandWord[i].candWord.autoPhrase->strCode) + iCodeInputCount;
 	strcpy (messageDown[uMessageDown].strMsg, pstr);
+
+	//뷴õƴ
+	if ((table[iTableIMIndex].bGetPY) && (strlen (tableCandWord[i].candWord.record->strHZ) == 2)) {
+	    PYGetPYByHZ (tableCandWord[i].candWord.record->strHZ, strPY);
+	    if (strPY[0]) {
+		strcat (messageDown[uMessageDown].strMsg, "(");
+		strcat (messageDown[uMessageDown].strMsg, strPY);
+		strcat (messageDown[uMessageDown].strMsg, ")");
+	    }
+	}
+
 	if (i != (iCandWordCount - 1)) {
 #ifdef _USE_XFT
 	    strcat (messageDown[uMessageDown].strMsg, "  ");
@@ -1516,7 +1541,19 @@ RECORD         *TableHasPhrase (char *strCode, char *strHZ)
     while (strCode[0] != recordIndex[i].cCode)
 	i++;
 
-    recTemp = recordIndex[i].record->prev;
+    /*recTemp = recordIndex[i].record->prev;
+       do {
+       if (strcmp (recTemp->strCode, strCode) > 0)
+       break;
+       else if (!strcmp (recTemp->strCode, strCode)) {
+       if (!strcmp (recTemp->strHZ, strHZ))     //ôѾڴʿ
+       return NULL;
+       }
+
+       recTemp = recTemp->next;
+       } while (recTemp != recordHead);
+     */
+    recTemp = recordIndex[i].record;
     while (recTemp != recordHead) {
 	if (strcmp (recTemp->strCode, strCode) > 0)
 	    break;
@@ -1824,7 +1861,7 @@ INPUT_RETURN_VALUE TableGetFHCandWords (SEARCH_MODE mode)
     int             i;
 
     if (!iFH)
-	return IRV_DO_NOTHING;
+	return IRV_DISPLAY_MESSAGE;
 
     strTemp[1] = '.';
     strTemp[2] = '\0';
