@@ -23,6 +23,8 @@ extern int      iMainWindowX;
 extern int      iMainWindowY;
 extern int      iInputWindowX;
 extern int      iInputWindowY;
+extern int      iTempInputWindowX;
+extern int      iTempInputWindowY;
 extern int      iInputWindowWidth;
 extern int      iInputWindowHeight;
 
@@ -85,6 +87,7 @@ extern int      i2ndSelectKey;
 extern int      i3rdSelectKey;
 
 extern char     strFontName[];
+extern char     strFontEnName[];
 
 extern ADJUSTORDER baseOrder;
 extern ADJUSTORDER phraseOrder;
@@ -102,6 +105,9 @@ extern Bool     bUseQW;
 extern Bool     bUseTable;
 
 extern Bool	bLumaQQ;
+extern char	cPYYCDZ[];
+
+extern Bool	bDoubleSwitchKey;
 
 #ifdef _USE_XFT
 extern Bool     bUseAA;
@@ -161,10 +167,14 @@ void LoadConfig (Bool bMode)
 	if (pstr[0] == '#')
 	    continue;
 
-	if (strstr (pstr, "ʾ=") && bMode) {
-	    pstr += 9;
+	if (strstr (pstr, "ʾ()=") && bMode) {
+	    pstr += 13;
 	    strcpy (strFontName, pstr);
 	}
+	if (strstr (pstr, "ʾ(Ӣ)=") && bMode) {
+	    pstr += 13;
+	    strcpy (strFontEnName, pstr);
+	}
 	else if (strstr (pstr, "ʾС=") && bMode) {
 	    pstr += 13;
 	    iFontSize = atoi (pstr);
@@ -330,6 +340,10 @@ void LoadConfig (Bool bMode)
 	    pstr += 17;
 	    SetSwitchKey (pstr);
 	}
+	else if (strstr (pstr, "˫Ӣл=")) {
+	    pstr += 15;
+	    bDoubleSwitchKey = atoi (pstr);
+	}
 	else if (strstr (pstr, "GBK֧=")) {
 	    pstr += 8;
 	    SetHotKey (pstr, hkGBK);
@@ -427,6 +441,11 @@ void LoadConfig (Bool bMode)
 	    pstr += 17;
 	    SetHotKey (pstr, hkPYDelUserPhr);
 	}
+	else if (strstr (str, "ƴԴʶּ=")) {
+	    pstr += 15;
+	    cPYYCDZ[0] = pstr[0];
+	    cPYYCDZ[1] = pstr[1];
+	}
 	else if (strstr (str, "ƴʽ=")) {
 	    pstr += 21;
 	    baseOrder = (ADJUSTORDER) atoi (pstr);
@@ -519,7 +538,8 @@ void SaveConfig (void)
     }
 
     fprintf (fp, "[]\n");
-    fprintf (fp, "ʾ=%s\n", strFontName);
+    fprintf (fp, "ʾ()=%s\n", strFontName);
+    fprintf (fp, "ʾ(Ӣ)=%s\n", strFontEnName);
     fprintf (fp, "ʾС=%d\n", iFontSize);
     fprintf (fp, "С=%d\n", iMainWindowFontSize);
 #ifdef _USE_XFT
@@ -569,6 +589,7 @@ void SaveConfig (void)
     fprintf (fp, "/ر뷨=CTRL_SPACE\n");
     fprintf (fp, "#ӢĿл ΪL_CTRL R_CTRL L_SHIFT R_SHIFT\n");
     fprintf (fp, "ӢĿл=L_CTRL\n");
+    fprintf (fp, "˫Ӣл=%d\n", bDoubleSwitchKey);
     fprintf (fp, "=CTRL_K\n");
     fprintf (fp, "GBK֧=CTRL_M\n");
     fprintf (fp, "֧=CTRL_L\n");
@@ -592,6 +613,8 @@ void SaveConfig (void)
     fprintf (fp, "ƴ=CTRL_8\n");
     fprintf (fp, "ɾƴ=CTRL_7\n");
     fprintf (fp, "ɾƴû=CTRL_DELETE\n");
+    fprintf (fp, "#ƴԴʶּȺźӼҪпո\n");
+    fprintf (fp, "ƴԴʶּ=%c%c\n", cPYYCDZ[0], cPYYCDZ[1]);
     fprintf (fp, "#ʽ˵0-->  1-->ٵ  2-->Ƶʵ\n");
     fprintf (fp, "ƴʽ=%d\n", baseOrder);
     fprintf (fp, "ƴʽ=%d\n", phraseOrder);
@@ -754,6 +777,9 @@ void SaveProfile (void)
     fprintf (fp, "ǰ뷨=%d\n", iIMIndex);
     fprintf (fp, "ֹüл=%d\n", bLocked);
     fprintf (fp, "ڼģʽ=%d\n", bCompactMainWindow);
+    
+    iTempInputWindowX = iInputWindowX;
+    iTempInputWindowY = iInputWindowY;
 
     fclose (fp);
 }
