@@ -4,8 +4,6 @@
 #include <stdio.h>
 #include "ime.h"
 
-#define MAX_HZ_SAVED	10
-
 void            LoadConfig (Bool bMode);
 void            SaveConfig (void);
 void            LoadProfile (void);
@@ -13,6 +11,11 @@ void            SaveProfile (void);
 void            SetHotKey (char *strKey, HOTKEYS * hotkey);
 int             CalculateRecordNumber (FILE * fpDict);
 void            SetSwitchKey (char *str);
-void		SetTriggerKeys (char *str);
-
+void            SetTriggerKeys (char *str);
+Bool            CheckHZCharset (char *strHZ);
+/*
+#if defined(DARWIN)
+int             ReverseInt (unsigned int pc_int);
+#endif
+*/
 #endif
