@@ -28,20 +28,27 @@ int             iScreen;
 
 #ifdef _USE_XFT
 XftFont        *xftFont;
+XftFont        *xftFontEn;	//Ӣ
 XftDraw        *xftDraw;
 XftFont        *xftMainWindowFont;
+XftFont        *xftMainWindowFontEn;
 Bool            bUseAA = True;
-int		iDefaultWidth = 0;
+int             iDefaultWidth = 0;
 #else
 XFontSet        fontSet;
 XFontSet        fontSetMainWindow;
-char		strUserLocale[50]="zh_CN.gb2312";
+char            strUserLocale[50] = "zh_CN.gb2312";
 #endif
 
 iconv_t         convUTF8;	//ֻXFTUTF8ִñUTF8֧
 
 int             iFontSize = 16;
-int             iMainWindowFontSize = 12;
+
+#ifdef _USE_XFT
+int             iMainWindowFontSize = 11;
+#else
+int             iMainWindowFontSize = 14;
+#endif
 
 GC              dimGC;
 GC              lightGC;
@@ -49,6 +56,7 @@ GC              lightGC;
 Bool            bIsUtf8 = False;
 
 char            strFontName[100] = "*";
+char            strFontEnName[100] = "Courier";
 
 extern Window   mainWindow;
 extern int      iMainWindowX;
@@ -64,7 +72,7 @@ extern IC      *CurrentIC;
 extern int      MAINWND_WIDTH;
 extern Bool     bCompactMainWindow;
 extern INT8     iIMIndex;
-extern CARD16	connect_id;
+extern CARD16   connect_id;
 
 Bool InitX (void)
 {
@@ -164,11 +172,13 @@ void InitGC (Window window)
 void CreateFont (void)
 {
     xftFont = XftFontOpen (dpy, iScreen, XFT_FAMILY, XftTypeString, strFontName, XFT_SIZE, XftTypeDouble, (double) iFontSize, XFT_ANTIALIAS, XftTypeBool, bUseAA, NULL);
+    xftFontEn = XftFontOpen (dpy, iScreen, XFT_FAMILY, XftTypeString, strFontEnName, XFT_SIZE, XftTypeDouble, (double) iFontSize, XFT_ANTIALIAS, XftTypeBool, bUseAA, NULL);
     xftMainWindowFont = XftFontOpen (dpy, iScreen, XFT_FAMILY, XftTypeString, strFontName, XFT_SIZE, XftTypeDouble, (double) iMainWindowFontSize, XFT_ANTIALIAS, XftTypeBool, bUseAA, XFT_WEIGHT, XftTypeInteger, XFT_WEIGHT_BOLD, NULL);
+    xftMainWindowFontEn = XftFontOpen (dpy, iScreen, XFT_FAMILY, XftTypeString, strFontEnName, XFT_SIZE, XftTypeDouble, (double) iMainWindowFontSize, XFT_ANTIALIAS, XftTypeBool, bUseAA, XFT_WEIGHT, XftTypeInteger, XFT_WEIGHT_BOLD, NULL);
 
     xftDraw = XftDrawCreate (dpy, inputWindow, DefaultVisual (dpy, DefaultScreen (dpy)), DefaultColormap (dpy, DefaultScreen (dpy)));
 
-    iDefaultWidth = StringWidth("", xftFont)/2 - 2;
+    iDefaultWidth = StringWidth ("", xftFont) / 2 - 2;
 }
 #else
 void CreateFont (void)
@@ -178,21 +188,34 @@ void CreateFont (void)
     char           *default_string;
     char            strFont[256];
 
-    if ( strUserLocale[0] )
-    	setlocale (LC_CTYPE, strUserLocale);
+    if (strUserLocale[0])
+	setlocale (LC_CTYPE, strUserLocale);
     else
-    	setlocale(LC_CTYPE,"");
-    sprintf (strFont, "-*-%s-medium-r-normal--%d-*-*-*-*-*-*-*,-*-*-medium-r-normal--%d-*-*-*-*-*-*-*", strFontName, iMainWindowFontSize, iMainWindowFontSize);
+	setlocale (LC_CTYPE, "");
+
+    sprintf (strFont, "-*-%s-medium-r-normal--%d-*-*-*-*-*-*-*,-*-%s-medium-r-normal--%d-*-*-*-*-*-*-*", strFontName, iMainWindowFontSize, strFontEnName, iMainWindowFontSize);
     fontSetMainWindow = XCreateFontSet (dpy, strFont, &missing_charsets, &num_missing_charsets, &default_string);
-    if (num_missing_charsets > 0)
-	fprintf (stderr, "Error: Cannot Create Chinese Fonts:\n\t%s\n", strFont);
+    if (num_missing_charsets > 0) {
+	fprintf (stderr, "Error: Cannot Create Chinese Fonts:\n\t%s\nUsing Default ...\n", strFont);
+	iMainWindowFontSize = 14;
+	sprintf (strFont, "-*-*-medium-r-normal--%d-*-*-*-*-*-*-*,-*-*-medium-r-normal--%d-*-*-*-*-*-*-*", iMainWindowFontSize, iMainWindowFontSize);
+	fontSetMainWindow = XCreateFontSet (dpy, strFont, &missing_charsets, &num_missing_charsets, &default_string);
+	if (num_missing_charsets > 0)
+	    fprintf (stderr, "Error: Cannot Create Chinese Fonts!\n\n");
+    }
 
-    sprintf (strFont, "-*-%s-medium-r-normal--%d-*-*-*-*-*-*-*,-*-*-medium-r-normal--%d-*-*-*-*-*-*-*", strFontName, iFontSize, iFontSize);
+    sprintf (strFont, "-*-%s-medium-r-normal--%d-*-*-*-*-*-*-*,-*-%s-medium-r-normal--%d-*-*-*-*-*-*-*", strFontName, iFontSize, strFontEnName, iFontSize);
     fontSet = XCreateFontSet (dpy, strFont, &missing_charsets, &num_missing_charsets, &default_string);
-    if (num_missing_charsets > 0)
-    	fprintf (stderr, "Error: Cannot Create Chinese Fonts:\n\t%s\n", strFont);
+    if (num_missing_charsets > 0) {
+	fprintf (stderr, "Error: Cannot Create Chinese Fonts:\n\t%s\nUsing Default ...\n", strFont);
+	iFontSize = 16;
+	sprintf (strFont, "-*-*-medium-r-normal--%d-*-*-*-*-*-*-*,-*-*-medium-r-normal--%d-*-*-*-*-*-*-*", iFontSize, iFontSize);
+	fontSet = XCreateFontSet (dpy, strFont, &missing_charsets, &num_missing_charsets, &default_string);
+	if (num_missing_charsets > 0)
+	    fprintf (stderr, "Error: Cannot Create Chinese Fonts!\n\n");
+    }
 
-    setlocale(LC_CTYPE,"");
+    setlocale (LC_CTYPE, "");
 /*
    SetLocale();*/
 }
@@ -258,15 +281,16 @@ void MyXEventHandler (XEvent * event)
 		iInputWindowX = event->xbutton.x;
 		iInputWindowY = event->xbutton.y;
 		MouseClick (&iInputWindowX, &iInputWindowY, 1);
-		SaveProfile ();
 	    }
 	    else if (event->xbutton.window == mainWindow) {
 		if (IsInBox (event->xbutton.x, event->xbutton.y, 1, 1, 16, 17)) {
 		    iMainWindowX = event->xbutton.x;
 		    iMainWindowY = event->xbutton.y;
-		    MouseClick (&iMainWindowX, &iMainWindowY, 0);
+		    if ( !MouseClick (&iMainWindowX, &iMainWindowY, 0) )
+			    SetIMState((ConnectIDGetState (connect_id) == IS_CHN)? False : True);
 		}
 	    }
+	    SaveProfile ();
 	    break;
 	}
 	break;
@@ -301,8 +325,8 @@ void MyXEventHandler (XEvent * event)
 
 	break;
     case FocusIn:
-	if (ConnectIDGetState(connect_id) == IS_CHN)
-		DisplayInputWindow ();
+	if (ConnectIDGetState (connect_id) == IS_CHN)
+	    DisplayInputWindow ();
 	if (hideMainWindow != HM_HIDE)
 	    XMapRaised (dpy, mainWindow);
 	break;
@@ -326,11 +350,10 @@ Bool IsInBox (int x0, int y0, int x1, int y1, int x2, int y2)
 int StringWidth (char *str, XftFont * font)
 {
     XGlyphInfo      extents;
-    char	    str1[100];
+    char            str1[100];
     char           *ps;
     size_t          l1, l2;
-    int		il;
-
+    int             il;
 
     if (!font)
 	return 0;
@@ -341,11 +364,11 @@ int StringWidth (char *str, XftFont * font)
 
     l1 = iconv (convUTF8, &str, &l1, &ps, &l2);
     *ps = '\0';
-    XftTextExtentsUtf8 (dpy, font, (FcChar8*)str1, strlen (str1), &extents);
-    if ( font!=xftFont)
-    	return extents.width;
+    XftTextExtentsUtf8 (dpy, font, (FcChar8 *) str1, strlen (str1), &extents);
+    if (font == xftMainWindowFont)
+	return extents.width;
 
-    return ((extents.width<(il*iDefaultWidth))?(il*iDefaultWidth):extents.width);
+    return ((extents.width < (il * iDefaultWidth)) ? (il * iDefaultWidth) : extents.width);
 }
 
 int FontHeight (XftFont * font)
@@ -365,9 +388,9 @@ int FontHeight (XftFont * font)
     ps1 = str1;
 
     l1 = iconv (convUTF8, &ps1, &l1, &ps2, &l2);
-    *ps2='\0';
+    *ps2 = '\0';
 
-    XftTextExtentsUtf8 (dpy, font, (FcChar8 *)str2, strlen (str2), &extents);
+    XftTextExtentsUtf8 (dpy, font, (FcChar8 *) str2, strlen (str2), &extents);
 
     return extents.height;
 }
@@ -417,9 +440,8 @@ void OutputString (Window window, XftFont * font, char *str, int x, int y, XColo
     l1 = strlen (str);
     l2 = 99;
     ps = strOutput;
-
-    l1 = iconv (convUTF8, (char **) (&str), &l1, &ps, &l2);
-    *ps='\0';
+    l1 = iconv (convUTF8, &str, &l1, &ps, &l2);
+    *ps = '\0';
 
     renderColor.red = color.red;
     renderColor.green = color.green;
@@ -428,7 +450,7 @@ void OutputString (Window window, XftFont * font, char *str, int x, int y, XColo
 
     XftColorAllocValue (dpy, DefaultVisual (dpy, DefaultScreen (dpy)), DefaultColormap (dpy, DefaultScreen (dpy)), &renderColor, &xftColor);
     XftDrawChange (xftDraw, window);
-    XftDrawStringUtf8 (xftDraw, &xftColor, font, x, y, (FcChar8 *)strOutput, strlen (strOutput));
+    XftDrawStringUtf8 (xftDraw, &xftColor, font, x, y, (FcChar8 *) strOutput, strlen (strOutput));
 
     XftColorFree (dpy, DefaultVisual (dpy, DefaultScreen (dpy)), DefaultColormap (dpy, DefaultScreen (dpy)), &xftColor);
 }
@@ -526,17 +548,17 @@ int FillImageByXPMData (XImage * pImage, char **apcData)
     return 0;
 }
 
-void MouseClick (int *x, int *y, int iWnd)
+Bool MouseClick (int *x, int *y, int iWnd)
 {
     XEvent          evtGrabbed;
+    Bool	    bMoved = False;
 
     // To motion the  window
     while (1) {
 	XMaskEvent (dpy, PointerMotionMask | ButtonReleaseMask | ButtonPressMask, &evtGrabbed);
 	if (ButtonRelease == evtGrabbed.xany.type) {
-	    if (Button1 == evtGrabbed.xbutton.button) {
+	    if (Button1 == evtGrabbed.xbutton.button)
 		break;
-	    }
 	}
 	else if (MotionNotify == evtGrabbed.xany.type) {
 	    static Time     LastTime;
@@ -554,7 +576,8 @@ void MouseClick (int *x, int *y, int iWnd)
 		XRaiseWindow (dpy, inputWindow);
 		break;
 	    }
-
+	    
+	    bMoved = True;
 	    LastTime = evtGrabbed.xmotion.time;
 	}
 
@@ -570,9 +593,11 @@ void MouseClick (int *x, int *y, int iWnd)
 
     *x = evtGrabbed.xmotion.x_root - *x;
     *y = evtGrabbed.xmotion.y_root - *y;
+    
+    return bMoved;
 }
 
-void WaitButtonRelease (XPoint * point)
+/*void WaitButtonRelease (XPoint * point)
 {
     XEvent          ev;
 
@@ -588,5 +613,5 @@ void WaitButtonRelease (XPoint * point)
 	}
     }
 }
-
+*/
 /* ****************************************************************** */
